## 1.2.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.2.0.0 (2022-12-14)

Update dj-database-url to 1.2.* (#9355)

## 1.0.0 (2022-08-05)

[stubsabot] Bump dj-database-url to 1.0.* (#8488)

* [stubsabot] Bump dj-database-url to 1.0.*

* Add DJANGO_VERSION

Co-authored-by: stubsabot <>
Co-authored-by: Sebastian Rittau <srittau@rittau.biz>

## 0.5.3 (2022-06-25)

dj-database-url, docopt, editdistance, first: check missing defs (#8154)

## 0.5.2 (2022-06-01)

`dj-database-url`: Add missing fields to `_DBConfig` TypedDict (#8008)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.5.1 (2022-05-29)

dj_database_url: make all keys optional in _DBConfig TypedDict (#7979)

Co-authored-by: Xavier Francisco <xavier.n.francisco@gmail.com>

## 0.5.0 (2022-05-28)

Add stubs for dj-database-url (#7972)

Co-authored-by: Xavier Francisco <xavier.n.francisco@gmail.com>

